@@ -1,7 +1,7 @@
 // fprint().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/string.h"
@@ -15,7 +15,7 @@ namespace cln {
 
 void fprint (std::ostream& stream, const cl_string& str)
 {
-	stream.write(str.asciz(),str.length());
+	stream.write(str.asciz(),str.size());
 }
 
 }  // namespace cln
