@@ -1,7 +1,7 @@
 // floor1().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/float.h"
@@ -9,7 +9,7 @@
 
 // Implementation.
 
-#include "cl_F.h"
+#include "float/cl_F.h"
 #include "cln/sfloat.h"
 #include "cln/ffloat.h"
 #include "cln/dfloat.h"
