@@ -1,10 +1,10 @@
 // futruncate().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
-#include "cl_FF.h"
+#include "float/ffloat/cl_FF.h"
 
 
 // Implementation.
