@@ -1,7 +1,7 @@
 // cl_LF equal_hashcode().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/lfloat.h"
@@ -9,9 +9,9 @@
 
 // Implementation.
 
-#include "cl_N.h"
-#include "cl_LF_impl.h"
-#include "cl_DS.h"
+#include "base/cl_N.h"
+#include "float/lfloat/cl_LF_impl.h"
+#include "base/digitseq/cl_DS.h"
 
 namespace cln {
 
