@@ -1,7 +1,7 @@
 // abs().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/float.h"
@@ -9,17 +9,17 @@
 
 // Implementation.
 
-#include "cl_F.h"
+#include "float/cl_F.h"
 #include "cln/sfloat.h"
 #include "cln/ffloat.h"
 #include "cln/dfloat.h"
 #include "cln/lfloat.h"
 
-#include "cl_inline.h"
-#include "cl_SF_minusp.cc"
-#include "cl_FF_minusp.cc"
-#include "cl_DF_minusp.cc"
-#include "cl_LF_minusp.cc"
+#include "base/cl_inline.h"
+#include "float/sfloat/elem/cl_SF_minusp.cc"
+#include "float/ffloat/elem/cl_FF_minusp.cc"
+#include "float/dfloat/elem/cl_DF_minusp.cc"
+#include "float/lfloat/elem/cl_LF_minusp.cc"
 
 namespace cln {
 
