@@ -1,7 +1,7 @@
 // cl_F equal_hashcode().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/float.h"
@@ -9,14 +9,14 @@
 
 // Implementation.
 
-#include "cl_N.h"
-#include "cl_F.h"
+#include "base/cl_N.h"
+#include "float/cl_F.h"
 
-#include "cl_inline.h"
-#include "cl_SF_eqhashcode.cc"
-#include "cl_FF_eqhashcode.cc"
-#include "cl_DF_eqhashcode.cc"
-#include "cl_LF_eqhashcode.cc"
+#include "base/cl_inline.h"
+#include "float/sfloat/misc/cl_SF_eqhashcode.cc"
+#include "float/ffloat/misc/cl_FF_eqhashcode.cc"
+#include "float/dfloat/misc/cl_DF_eqhashcode.cc"
+#include "float/lfloat/misc/cl_LF_eqhashcode.cc"
 
 namespace cln {
 
