@@ -1,25 +1,25 @@
 // cl_ln10().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
-#include "cl_F_tran.h"
+#include "float/transcendental/cl_F_tran.h"
 
 
 // Implementation.
 
-#include "cl_F.h"
-#include "cl_LF.h"
+#include "float/cl_F.h"
+#include "float/lfloat/cl_LF.h"
 
 namespace cln {
 
 const cl_F cl_ln10 (const cl_F& y)
 {
 	floattypecase(y
-	,	return cl_SF_ln10;
-	,	return cl_FF_ln10;
-	,	return cl_DF_ln10;
+	,	return cl_SF_ln10();
+	,	return cl_FF_ln10();
+	,	return cl_DF_ln10();
 	,	return cl_ln10(TheLfloat(y)->len);
 	);
 }
