@@ -1,7 +1,7 @@
 // logior().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/integer.h"
@@ -9,9 +9,9 @@
 
 // Implementation.
 
-#include "cl_I.h"
-#include "cl_DS.h"
-#include "cl_I_log.h"
+#include "integer/cl_I.h"
+#include "base/digitseq/cl_DS.h"
+#include "integer/bitwise/cl_I_log.h"
 
 namespace cln {
 
