@@ -1,7 +1,7 @@
 // signum().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/integer.h"
@@ -9,12 +9,11 @@
 
 // Implementation.
 
-#include "cl_I.h"
+#include "integer/cl_I.h"
 
 namespace cln {
 
-MAYBE_INLINE
-const cl_I signum (const cl_I& x)
+CL_INLINE const cl_I CL_INLINE_DECL(signum) (const cl_I& x)
 {
 	if (minusp(x)) { return -1; } // x<0 -> -1
 	elif (zerop(x)) { return 0; } // x=0 -> 0
