@@ -1,7 +1,7 @@
 // square().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/real.h"
@@ -9,7 +9,7 @@
 
 // Implementation.
 
-#include "cl_R.h"
+#include "real/cl_R.h"
 #include "cln/rational.h"
 #include "cln/integer.h"
 #include "cln/float.h"
@@ -17,8 +17,8 @@
 #include "cln/ffloat.h"
 #include "cln/dfloat.h"
 #include "cln/lfloat.h"
-#include "cl_RA.h"
-#include "cl_I.h"
+#include "rational/cl_RA.h"
+#include "integer/cl_I.h"
 
 namespace cln {
 
