@@ -1,10 +1,10 @@
 // format_cardinal().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
-#include "cl_format.h"
+#include "real/format-output/cl_format.h"
 
 
 // Implementation.
