@@ -2,7 +2,7 @@
 #include <cln/io.h>
 #include <cln/float.h>
 #include <cln/lfloat.h>
-#include "cl_LF.h"
+#include "float/lfloat/cl_LF.h"
 #include <cln/complex.h>
 #include <cln/complex_io.h>
 #include <cln/real.h>
@@ -11,6 +11,8 @@
 #include <cstring>
 #include <cln/timing.h>
 using namespace cln;
+#include <iostream>
+using namespace std;
 
 int main (int argc, char * argv[])
 {
